Connectivity class
Discover network connectivity configurations: Distinguish between WI-FI and cellular, check WI-FI status and more.
Constructors
- Connectivity()
-
Constructs a singleton instance of Connectivity.
factory
- Connectivity.getInstance()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onConnectivityChanged
→ Stream<
ConnectivityState> -
Exposes connectivity update events from the platform.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkConnectivity(
) → Future< ConnectivityState> - Checks the connection status of the device.
-
checkVPNConnectivity(
) → Future< ConnectivityState> - only supported on iOS and macOS
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAddressCheckOption(
String address) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited