ConnectivityState enum

Inheritance
Available extensions

Values

wifi → const ConnectivityState

WiFi: Device connected via Wi-Fi

mobile → const ConnectivityState

Mobile: Device connected to cellular network

none → const ConnectivityState

None: Device not connected to any network

restricted → const ConnectivityState

Restricted: Device connected to Wi-Fi/cellular, not accessible to address checked

vpn → const ConnectivityState

VPN: Device connected to a VPN, Only Supported on iOS and macOS

unknown → const ConnectivityState

Unknown: not sure if Device is connected to a VPN

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ConnectivityState>
A constant List of the values in this enum, in order of their declaration.